rotation_stage library
A four-sided stage for representing 3D objects with four widgets
Classes
- RotationStage
- A widget that allows for rotating a widget with four sides in pseudo-3D, with a bar of handles for switching between the sides.
- RotationStageBar
- A bar that displays the handles for the RotationStage.
- RotationStageContent
- A widget that displays the content of the RotationStage and applies the visual transformations to the sides when roataing the stage.
- RotationStageController
- A controller for the RotationStage.
- RotationStageHandle
- A handle for the RotationStage that represents one side of the stage.
- RotationStageLabelData
- Holds the labels for each RotationStageSide.
- RotationStageLabels
- An InheritedWidget that holds the RotationStageLabelData for the RotationStage and provides them to the widgets below it in the widget tree.
Enums
- RotationStageSide
- Represents one of the four sides of the RotationStage.
Constants
- kInfiniteScrollStartPage → const int
- A workaround to achieve pseudo-infinite scroll with a default Flutter PageController.
Typedefs
- RotationStageBuilder = Widget Function(int index, RotationStageSide side, double currentPage)
- The builder function for one side of the RotationStage.